@@ -71,7 +71,7 @@ Possible values:
     * metadef_tag
 
     For a complete listing and description of each event refer to:
-    http://docs.openstack.org/developer/glance/notifications.html
+    https://docs.openstack.org/glance/latest/admin/notifications.html
 
     The values must be specified as: <group_name>.<event_name>
     For example: image.create,task.success,metadef_tag
@@ -167,8 +167,8 @@ def format_image_notification(image):
 
 
 def format_image_member_notification(image_member):
-    """Given a glance.domain.ImageMember object, return a dictionary of relevant
-    notification information.
+    """Given a glance.domain.ImageMember object, return a dictionary of
+    relevant notification information.
     """
     return {
         'image_id': image_member.image_id,
