@@ -15,12 +15,9 @@
 
 import jsonschema
 from oslo_utils import encodeutils
-import six
 
 from glance.common import exception
-from glance import i18n
-
-_ = i18n._
+from glance.i18n import _
 
 
 class Schema(object):
@@ -44,7 +41,7 @@ class Schema(object):
 
     def filter(self, obj):
         filtered = {}
-        for key, value in six.iteritems(obj):
+        for key, value in obj.items():
             if self._filter_func(self.properties, key):
                 filtered[key] = value
 
