@@ -45,18 +45,11 @@ class TestWSGIServer(functional.FunctionalTest):
         port = server.sock.getsockname()[1]
 
         def get_request(delay=0.0):
-            # Socket timeouts are handled rather inconsistently on Windows.
-            # recv may either return nothing OR raise a ConnectionAbortedError.
-            exp_exc = OSError if os.name == 'nt' else ()
-
-            try:
-                sock = socket.socket()
-                sock.connect(('127.0.0.1', port))
-                time.sleep(delay)
-                sock.send(b'GET / HTTP/1.1\r\nHost: localhost\r\n\r\n')
-                return sock.recv(1024)
-            except exp_exc:
-                return None
+            sock = socket.socket()
+            sock.connect(('127.0.0.1', port))
+            time.sleep(delay)
+            sock.send(b'GET / HTTP/1.1\r\nHost: localhost\r\n\r\n')
+            return sock.recv(1024)
 
         # Should succeed - no timeout
         self.assertIn(greetings, get_request())
