@@ -21,11 +21,11 @@ from unittest import mock
 import glance_store
 from oslo_concurrency import processutils
 from oslo_config import cfg
+from oslo_utils.imageutils import format_inspector
 
 import glance.async_.flows.api_image_import as import_flow
 import glance.async_.flows.plugins.image_conversion as image_conversion
 from glance.async_ import utils as async_utils
-from glance.common import format_inspector
 from glance.common import utils
 from glance import domain
 from glance import gateway
@@ -97,9 +97,9 @@ class TestConvertImageTask(test_utils.BaseTestCase):
                                                        self.task.task_id)
 
         self.detect_file_format_mock = mock.MagicMock()
-        self.useFixture(fixtures.MockPatch('glance.common.format_inspector.'
-                                           'detect_file_format',
-                                           self.detect_file_format_mock))
+        self.useFixture(fixtures.MockPatch(
+            'oslo_utils.imageutils.format_inspector.detect_file_format',
+            self.detect_file_format_mock))
 
     @mock.patch.object(os, 'stat')
     @mock.patch.object(os, 'remove')
@@ -125,8 +125,7 @@ class TestConvertImageTask(test_utils.BaseTestCase):
                 jloads_mock.return_value = {'format': 'raw',
                                             'virtual-size': 456}
                 inspector = self.detect_file_format_mock.return_value
-                inspector.__str__.return_value = 'raw'
-                inspector.safety_check.return_value = True
+                inspector.__str__.side_effect = ['raw', 'qcow2']
                 image_convert.execute('file:///test/path.raw')
 
                 # NOTE(hemanthm): Asserting that the source format is passed
@@ -164,7 +163,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         self.img_repo.get.return_value = image
         inspector = self.detect_file_format_mock.return_value
         inspector.__str__.return_value = 'iso'
-        inspector.safety_check.return_value = True
 
         image_convert.execute('file:///test/path.iso')
         self.assertEqual(fmt, image.disk_format)
@@ -206,7 +204,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         with mock.patch.object(processutils, 'execute') as exc_mock:
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'qcow2'
-            inspector.safety_check.return_value = True
             exc_mock.side_effect = OSError('fail')
             self.assertRaises(OSError,
                               convert.execute, 'file:///test/path.raw')
@@ -227,7 +224,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
             exc_mock.return_value = '', 'some error'
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'qcow2'
-            inspector.safety_check.return_value = True
             self.assertRaises(RuntimeError,
                               convert.execute, 'file:///test/path.raw')
             exc_mock.assert_called_once_with(
@@ -249,7 +245,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         with mock.patch.object(processutils, 'execute') as exc_mock:
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'qcow2'
-            inspector.safety_check.return_value = True
             exc_mock.return_value = json.dumps(data), ''
             e = self.assertRaises(RuntimeError,
                                   convert.execute, 'file:///test/path.qcow')
@@ -269,7 +264,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
             exc_mock.return_value = json.dumps(data), ''
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'qcow2'
-            inspector.safety_check.return_value = True
             e = self.assertRaises(RuntimeError,
                                   convert.execute, 'file:///test/path.qcow')
             self.assertEqual('QCOW images with data-file set are not allowed',
@@ -284,7 +278,8 @@ class TestConvertImageTask(test_utils.BaseTestCase):
     def test_image_convert_fails_inspection_safety_check(self):
         convert = self._setup_image_convert_info_fail()
         inspector = self.detect_file_format_mock.return_value
-        inspector.safety_check.return_value = False
+        inspector.safety_check.side_effect = (
+            format_inspector.SafetyCheckFailed({}))
         self.assertRaisesRegex(RuntimeError,
                                'Image has disallowed configuration',
                                convert.execute, 'file:///test/path.qcow')
@@ -314,8 +309,7 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         convert = self._setup_image_convert_info_fail(disk_format='vmdk')
         with mock.patch.object(processutils, 'execute') as exc_mock:
             inspector = self.detect_file_format_mock.return_value
-            inspector.__str__.return_value = 'vmdk'
-            inspector.safety_check.return_value = True
+            inspector.__str__.side_effect = ['vmdk', 'qcow2']
             exc_mock.return_value = json.dumps(data), ''
             convert.execute('file:///test/path.vmdk')
 
@@ -347,7 +341,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         with mock.patch.object(processutils, 'execute') as exc_mock:
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'raw'
-            inspector.safety_check.return_value = True
             exc_mock.side_effect = [('{"format":"raw"}', ''),
                                     OSError('convert_fail')]
             self.assertRaises(OSError,
@@ -373,7 +366,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
                                     ('', 'some error')]
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'raw'
-            inspector.safety_check.return_value = True
             self.assertRaises(RuntimeError,
                               convert.execute, 'file:///test/path.raw')
             exc_mock.assert_has_calls(
@@ -396,7 +388,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
             exc_mock.return_value = ('{}', '')
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'qcow2'
-            inspector.safety_check.return_value = True
             exc = self.assertRaises(RuntimeError,
                                     convert.execute, 'file:///test/path.raw')
             self.assertIn('Image metadata disagrees about format', str(exc))
@@ -429,7 +420,6 @@ class TestConvertImageTask(test_utils.BaseTestCase):
                 '{"format": "qcow2", "virtual-size": 123}', '')
             inspector = self.detect_file_format_mock.return_value
             inspector.__str__.return_value = 'qcow2'
-            inspector.safety_check.return_value = True
             convert.execute('file:///test/path.qcow')
             # Make sure we only called qemu-img for inspection, not conversion
             exc_mock.assert_called_once_with(
@@ -445,6 +435,71 @@ class TestConvertImageTask(test_utils.BaseTestCase):
         image = self.img_repo.get.return_value
         self.assertEqual(123, image.virtual_size)
 
+    @mock.patch.object(os, 'stat')
+    @mock.patch.object(os, 'remove', new=mock.MagicMock())
+    def _test_image_convert_inspect_target_format(
+            self, mock_stat,
+            out_format='raw', src_format='qcow2', dst_format='raw',
+            dest_safe_fails=None):
+        self.config(output_format=out_format,
+                    group='image_conversion')
+        convert = self._setup_image_convert_info_fail()
+        mock_stat.return_value.st_size = 123
+        with mock.patch.object(processutils, 'execute') as exc_mock:
+            exc_mock.return_value = (
+                '{"format": "%s", "virtual-size": 123}' % src_format, '')
+            pre_inspector = mock.MagicMock()
+            post_inspector = mock.MagicMock()
+            self.detect_file_format_mock.side_effect = [
+                pre_inspector, post_inspector]
+            pre_inspector.__str__.return_value = pre_inspector.NAME = (
+                src_format)
+            post_inspector.__str__.return_value = post_inspector.NAME = (
+                dst_format)
+            if dest_safe_fails:
+                post_inspector.safety_check.side_effect = (
+                    format_inspector.SafetyCheckFailed(
+                        {r: 'fail' for r in dest_safe_fails}))
+            convert.execute('file:///test/path.%s' % src_format)
+
+    def test_image_convert_ignores_configured_gpt_safety(self):
+        # Conversion succeeds, finds the proper format, but fails safety check
+        self.config(gpt_safety_checks_nonfatal=['mbr'],
+                    group='image_format')
+
+        # GPT that fails only mbr should be allowed to proceed
+        self._test_image_convert_inspect_target_format(
+            out_format='raw', dst_format='gpt', dest_safe_fails=['mbr'])
+
+        # GPT that fails something not configured as non-fatal is rejected
+        self.assertRaisesRegex(
+            RuntimeError, 'disallowed configuration',
+            self._test_image_convert_inspect_target_format,
+            out_format='raw', dst_format='gpt', dest_safe_fails=['mbr',
+                                                                 'pmbr'])
+
+        # An non-GPT format that fails something configured as non-fatal for
+        # GPT-only is rejected
+        self.assertRaisesRegex(
+            RuntimeError, 'disallowed configuration',
+            self._test_image_convert_inspect_target_format,
+            out_format='vmdk', dst_format='vmdk', dest_safe_fails=['mbr'])
+
+    def test_image_convert_fails_target_format_raw(self):
+        # Uploaded a qcow with a vmdk inside it. Conversion expects a
+        # raw, but finds the wrong type and should abort
+        self.assertRaisesRegex(
+            RuntimeError, 'image in unexpected format',
+            self._test_image_convert_inspect_target_format,
+            dst_format='vmdk')
+
+    def test_image_convert_fails_target_format_unsafe(self):
+        # Conversion succeeds, finds the proper format, but fails safety check
+        self.assertRaisesRegex(
+            RuntimeError, 'disallowed configuration',
+            self._test_image_convert_inspect_target_format,
+            out_format='vmdk', dst_format='vmdk', dest_safe_fails=['header'])
+
     def _set_image_conversion(self, mock_os_remove, stores=[]):
         mock_os_remove.return_value = None
         wrapper = mock.MagicMock()
