@@ -606,8 +606,6 @@ class ServerTest(test_utils.BaseTestCase):
     def test_number_of_workers_posix(self, mock_migrate_db, mock_prefetcher):
         """Ensure the number of workers matches num cpus limited to 8."""
         mock_migrate_db.return_value = False
-        if os.name == 'nt':
-            raise self.skipException("Unsupported platform.")
 
         def pid():
             i = 1
@@ -732,9 +730,6 @@ class GetSocketTestCase(test_utils.BaseTestCase):
         self.useFixture(fixtures.MonkeyPatch(
             "glance.common.wsgi.time.time",
             mock.Mock(side_effect=[0, 1, 5, 10, 20, 35])))
-        self.useFixture(fixtures.MonkeyPatch(
-            "glance.common.wsgi.utils.validate_key_cert",
-            lambda *x: None))
         wsgi.CONF.tcp_keepidle = 600
 
     @mock.patch.object(prefetcher, 'Prefetcher')
